==> mcu_plus_sdk_am64x_07_03_00_19_docs_only.tar.xz: mcu_plus_sdk_am64x_07_03_00_19_docs_only/docs/api_guide_am64x/group__BOARD__ETHPHY__MODULE.js <==
var group__BOARD__ETHPHY__MODULE =
[
    [ "ETHPHY_Params", "structETHPHY__Params.html", [
      [ "reserved", "structETHPHY__Params.html#af389ecbf2f1215df555b87137f75b3e6", null ]
    ] ],
    [ "ETHPHY_Fxns", "structETHPHY__Fxns.html", [
      [ "openFxn", "structETHPHY__Fxns.html#a64cea306569fa24722ed1c86d4e9e9c2", null ],
      [ "closeFxn", "structETHPHY__Fxns.html#a081058741e0d5cda91a68a291308b7f4", null ],
      [ "commandFxn", "structETHPHY__Fxns.html#a43255508d3a6a6039b2d57a16365a467", null ]
    ] ],
    [ "ETHPHY_Attrs", "structETHPHY__Attrs.html", [
      [ "mdioBaseAddress", "structETHPHY__Attrs.html#a9a4df46a57ee9ea0bc966dfbd3a85a51", null ],
      [ "phyAddress", "structETHPHY__Attrs.html#aeb591c6878818f9b25cfb10df464b498", null ]
    ] ],
    [ "ETHPHY_Config", "structETHPHY__Config.html", [
      [ "attrs", "structETHPHY__Config.html#a98af9c12c14d3551d8c55f3a8d957899", null ],
      [ "fxns", "structETHPHY__Config.html#ac843bfd8305281e8873dab406fbc00f0", null ],
      [ "object", "structETHPHY__Config.html#ada87356f6f69f640324f7ec243cb230d", null ]
    ] ],
    [ "ETHPHY_SpeedDuplexityConfig", "structETHPHY__SpeedDuplexityConfig.html", [
      [ "config", "structETHPHY__SpeedDuplexityConfig.html#ac8a2bfbf916213caf6012dbf96aa842e", null ]
    ] ],
    [ "ETHPHY_CMD_ENABLE_MII", "group__BOARD__ETHPHY__MODULE.html#ga148127b94a1165c90d0367726fd7609c", null ],
    [ "ETHPHY_CMD_SOFT_RESTART", "group__BOARD__ETHPHY__MODULE.html#ga54463d7b7298b502a3ed539a56348a9c", null ],
    [ "ETHPHY_CMD_ENABLE_AUTO_MDIX", "group__BOARD__ETHPHY__MODULE.html#ga9399f42d481622944ab00c5eb5658845", null ],
    [ "ETHPHY_CMD_VERIFY_IDENTIFIER_REGISTER", "group__BOARD__ETHPHY__MODULE.html#ga0a4326f41500c990258092fd3fdf4b85", null ],
    [ "ETHPHY_CMD_DISABLE_1000M_ADVERTISEMENT", "group__BOARD__ETHPHY__MODULE.html#ga70fd0659e0237cd95e8f161d958e7588", null ],
    [ "ETHPHY_CMD_ENABLE_FAST_LINK_DOWN_DETECTION", "group__BOARD__ETHPHY__MODULE.html#ga17df35c07a5ac06774c81641820b7308", null ],
    [ "ETHPHY_CMD_CONFIGURE_LED_SOURCE", "group__BOARD__ETHPHY__MODULE.html#ga680898e9adea5e08921d14e2165ec523", null ],
    [ "ETHPHY_CMD_CONFIGURE_LED_BLINK_RATE", "group__BOARD__ETHPHY__MODULE.html#ga0a06935770809643dd680d6eca1fea0c", null ],
    [ "ETHPHY_CMD_ENABLE_EXTENDED_FD_ABILITY", "group__BOARD__ETHPHY__MODULE.html#gab3207fcf6c0b35cef414481685f3a6ce", null ],
    [ "ETHPHY_CMD_ENABLE_ODD_NIBBLE_DETECTION", "group__BOARD__ETHPHY__MODULE.html#ga31edf29e040fc6fd3739972b60ea301f", null ],
    [ "ETHPHY_CMD_ENABLE_ENHANCED_IPG_DETECTION", "group__BOARD__ETHPHY__MODULE.html#ga8044a140d7f1c572c160a8b2cc0a4aa2", null ],
    [ "ETHPHY_CMD_GET_LINK_STATUS", "group__BOARD__ETHPHY__MODULE.html#ga76ccf5cf33179d6e85fce3d954bdeed2", null ],
    [ "ETHPHY_CMD_GET_SPEED_AND_DUPLEXITY", "group__BOARD__ETHPHY__MODULE.html#gac3dcc2d22693ed1412a9c5b75e83e94e", null ],
    [ "ETHPHY_CMD_SET_SPEED_AND_DUPLEXITY", "group__BOARD__ETHPHY__MODULE.html#ga6eb7183f6bb98204a1ccb185e485353c", null ],
    [ "ETHPHY_SPEED_DUPLEXITY_CONFIG_AUTONEG", "group__BOARD__ETHPHY__MODULE.html#gadd6dc21b76177116691ae658ddf6521d", null ],
    [ "ETHPHY_SPEED_DUPLEXITY_CONFIG_10FD", "group__BOARD__ETHPHY__MODULE.html#ga3d9ee1e6e838ca94f782f84bfdd394e1", null ],
    [ "ETHPHY_SPEED_DUPLEXITY_CONFIG_100FD", "group__BOARD__ETHPHY__MODULE.html#ga492fc80586b0cd3a35c2ac1636bb025e", null ],
    [ "ETHPHY_SPEED_DUPLEXITY_CONFIG_1000FD", "group__BOARD__ETHPHY__MODULE.html#ga772cdcbec01cc3af0cdc4cccdfce870b", null ],
    [ "ETHPHY_SPEED_DUPLEXITY_CONFIG_10HD", "group__BOARD__ETHPHY__MODULE.html#gaf3e651da2f52c99b209d0312955e67e3", null ],
    [ "ETHPHY_SPEED_DUPLEXITY_CONFIG_100HD", "group__BOARD__ETHPHY__MODULE.html#ga96cc7ba5aa6ef1a0a432882a85562409", null ],
    [ "ETHPHY_SPEED_DUPLEXITY_CONFIG_1000HD", "group__BOARD__ETHPHY__MODULE.html#ga166814a652ffcaed900c892dcdb4afdf", null ],
    [ "ETHPHY_SPEED_DUPLEXITY_CONFIG_INVALID", "group__BOARD__ETHPHY__MODULE.html#gad805867bf65f87a07da043840207c2e4", null ],
    [ "ETHPHY_Handle", "group__BOARD__ETHPHY__MODULE.html#gae315fef8811154996f11b3f1878b6573", null ],
    [ "ETHPHY_Config", "group__BOARD__ETHPHY__MODULE.html#ga40b6588410cc7dec913f24dec2df2fe6", null ],
    [ "ETHPHY_Params", "group__BOARD__ETHPHY__MODULE.html#ga4042f60e561d0b93b4595bd6c7ab9d02", null ],
    [ "ETHPHY_OpenFxn", "group__BOARD__ETHPHY__MODULE.html#ga2f1dc6b749f150e94a8c77959ca6d90b", null ],
    [ "ETHPHY_CloseFxn", "group__BOARD__ETHPHY__MODULE.html#ga6d82e74ae90392733826413aaf1838e4", null ],
    [ "ETHPHY_CommandFxn", "group__BOARD__ETHPHY__MODULE.html#ga91c0f1a8b7f6e119af13a5f2ea717dd9", null ],
    [ "ETHPHY_Params_init", "group__BOARD__ETHPHY__MODULE.html#ga8ab192f315a9c2a65b946d393355346d", null ],
    [ "ETHPHY_open", "group__BOARD__ETHPHY__MODULE.html#gad9b0099a1138e12179ea1631bb2fb4bc", null ],
    [ "ETHPHY_close", "group__BOARD__ETHPHY__MODULE.html#ga698f42b85b914bea65c0573db3e56cfd", null ],
    [ "ETHPHY_command", "group__BOARD__ETHPHY__MODULE.html#gaf3051e618069fad2c94570cb618812e7", null ],
    [ "ETHPHY_getAttrs", "group__BOARD__ETHPHY__MODULE.html#ga567c1acffdb64b227ddc69c609c7093d", null ]
];

==> mcu_plus_sdk_am64x_08_00_00_21_docs_only.tar.xz: mcu_plus_sdk_am64x_08_00_00_21_docs_only/docs/api_guide_am64x/group__BOARD__ETHPHY__MODULE.js <==
var group__BOARD__ETHPHY__MODULE =
[
    [ "ETHPHY_Params", "structETHPHY__Params.html", [
      [ "reserved", "structETHPHY__Params.html#af389ecbf2f1215df555b87137f75b3e6", null ]
    ] ],
    [ "ETHPHY_Fxns", "structETHPHY__Fxns.html", [
      [ "openFxn", "structETHPHY__Fxns.html#a64cea306569fa24722ed1c86d4e9e9c2", null ],
      [ "closeFxn", "structETHPHY__Fxns.html#a081058741e0d5cda91a68a291308b7f4", null ],
      [ "commandFxn", "structETHPHY__Fxns.html#a43255508d3a6a6039b2d57a16365a467", null ]
    ] ],
    [ "ETHPHY_Attrs", "structETHPHY__Attrs.html", [
      [ "mdioBaseAddress", "structETHPHY__Attrs.html#a9a4df46a57ee9ea0bc966dfbd3a85a51", null ],
      [ "phyAddress", "structETHPHY__Attrs.html#aeb591c6878818f9b25cfb10df464b498", null ]
    ] ],
    [ "ETHPHY_Config", "structETHPHY__Config.html", [
      [ "attrs", "structETHPHY__Config.html#a98af9c12c14d3551d8c55f3a8d957899", null ],
      [ "fxns", "structETHPHY__Config.html#ac843bfd8305281e8873dab406fbc00f0", null ],
      [ "object", "structETHPHY__Config.html#ada87356f6f69f640324f7ec243cb230d", null ]
    ] ],
    [ "ETHPHY_SpeedDuplexConfig", "structETHPHY__SpeedDuplexConfig.html", [
      [ "config", "structETHPHY__SpeedDuplexConfig.html#a790b1cb3380ad6003d299028b0f64d7e", null ]
    ] ],
    [ "ETHPHY_CMD_ENABLE_MII", "group__BOARD__ETHPHY__MODULE.html#ga148127b94a1165c90d0367726fd7609c", null ],
    [ "ETHPHY_CMD_SOFT_RESTART", "group__BOARD__ETHPHY__MODULE.html#ga54463d7b7298b502a3ed539a56348a9c", null ],
    [ "ETHPHY_CMD_ENABLE_AUTO_MDIX", "group__BOARD__ETHPHY__MODULE.html#ga9399f42d481622944ab00c5eb5658845", null ],
    [ "ETHPHY_CMD_VERIFY_IDENTIFIER_REGISTER", "group__BOARD__ETHPHY__MODULE.html#ga0a4326f41500c990258092fd3fdf4b85", null ],
    [ "ETHPHY_CMD_DISABLE_1000M_ADVERTISEMENT", "group__BOARD__ETHPHY__MODULE.html#ga70fd0659e0237cd95e8f161d958e7588", null ],
    [ "ETHPHY_CMD_ENABLE_FAST_LINK_DOWN_DETECTION", "group__BOARD__ETHPHY__MODULE.html#ga17df35c07a5ac06774c81641820b7308", null ],
    [ "ETHPHY_CMD_CONFIGURE_LED_SOURCE", "group__BOARD__ETHPHY__MODULE.html#ga680898e9adea5e08921d14e2165ec523", null ],
    [ "ETHPHY_CMD_CONFIGURE_LED_BLINK_RATE", "group__BOARD__ETHPHY__MODULE.html#ga0a06935770809643dd680d6eca1fea0c", null ],
    [ "ETHPHY_CMD_ENABLE_EXTENDED_FD_ABILITY", "group__BOARD__ETHPHY__MODULE.html#gab3207fcf6c0b35cef414481685f3a6ce", null ],
    [ "ETHPHY_CMD_ENABLE_ODD_NIBBLE_DETECTION", "group__BOARD__ETHPHY__MODULE.html#ga31edf29e040fc6fd3739972b60ea301f", null ],
    [ "ETHPHY_CMD_ENABLE_ENHANCED_IPG_DETECTION", "group__BOARD__ETHPHY__MODULE.html#ga8044a140d7f1c572c160a8b2cc0a4aa2", null ],
    [ "ETHPHY_CMD_GET_LINK_STATUS", "group__BOARD__ETHPHY__MODULE.html#ga76ccf5cf33179d6e85fce3d954bdeed2", null ],
    [ "ETHPHY_CMD_GET_SPEED_AND_DUPLEX_CONFIG", "group__BOARD__ETHPHY__MODULE.html#gaad57e1257a69b29716b3ded76d623ab1", null ],
    [ "ETHPHY_CMD_SET_SPEED_AND_DUPLEX_CONFIG", "group__BOARD__ETHPHY__MODULE.html#gaf83ec9313054a40d0e35d607dc74d14f", null ],
    [ "ETHPHY_CMD_ENABLE_LOW_LATENCY_10M_100M_RGMII", "group__BOARD__ETHPHY__MODULE.html#gabeab20f036811afd96b8a4ab6f3f01fe", null ],
    [ "ETHPHY_CMD_SET_RX_HALF_FULL_THRESHOLD_RGMII", "group__BOARD__ETHPHY__MODULE.html#gaaa342b305ec89709c5fa96cf95b2f4de", null ],
    [ "ETHPHY_CMD_SET_TX_HALF_FULL_THRESHOLD_RGMII", "group__BOARD__ETHPHY__MODULE.html#ga953e2ca7c00b09186bc1ee88b42c1e48", null ],
    [ "ETHPHY_CMD_GET_AUTONEG_COMPLETE_STATUS", "group__BOARD__ETHPHY__MODULE.html#gafd2b88441d80594bf3ecd916b8f818d3", null ],
    [ "ETHPHY_CMD_GET_LINK_PARTNER_AUTONEG_ABILITY", "group__BOARD__ETHPHY__MODULE.html#ga09fa2791a95fb138fc93e841b49230cb", null ],
    [ "ETHPHY_SPEED_DUPLEX_CONFIG_AUTONEG", "group__BOARD__ETHPHY__MODULE.html#ga921e37a6a2dbaad665f0f9f37781e448", null ],
    [ "ETHPHY_SPEED_DUPLEX_CONFIG_10FD", "group__BOARD__ETHPHY__MODULE.html#ga7c02e081a6eaa87bed947ac25579dc6d", null ],
    [ "ETHPHY_SPEED_DUPLEX_CONFIG_100FD", "group__BOARD__ETHPHY__MODULE.html#ga93c1028843db699cd1cceb1bca0da7a1", null ],
    [ "ETHPHY_SPEED_DUPLEX_CONFIG_1000FD", "group__BOARD__ETHPHY__MODULE.html#ga948178f3281ff992f8367527c6053a2b", null ],
    [ "ETHPHY_SPEED_DUPLEX_CONFIG_10HD", "group__BOARD__ETHPHY__MODULE.html#ga12357295dbfb128a326ccc1155352ce8", null ],
    [ "ETHPHY_SPEED_DUPLEX_CONFIG_100HD", "group__BOARD__ETHPHY__MODULE.html#gaae48047a79e2cd3686f13d594b9ec536", null ],
    [ "ETHPHY_SPEED_DUPLEX_CONFIG_1000HD", "group__BOARD__ETHPHY__MODULE.html#ga8c005feb91a4a0b9e5ee48f170e4b96e", null ],
    [ "ETHPHY_SPEED_DUPLEX_CONFIG_INVALID", "group__BOARD__ETHPHY__MODULE.html#gaafb5199d31ddb8403b59dd53744e0323", null ],
    [ "ETHPHY_Handle", "group__BOARD__ETHPHY__MODULE.html#gae315fef8811154996f11b3f1878b6573", null ],
    [ "ETHPHY_Config", "group__BOARD__ETHPHY__MODULE.html#ga40b6588410cc7dec913f24dec2df2fe6", null ],
    [ "ETHPHY_Params", "group__BOARD__ETHPHY__MODULE.html#ga4042f60e561d0b93b4595bd6c7ab9d02", null ],
    [ "ETHPHY_OpenFxn", "group__BOARD__ETHPHY__MODULE.html#ga2f1dc6b749f150e94a8c77959ca6d90b", null ],
    [ "ETHPHY_CloseFxn", "group__BOARD__ETHPHY__MODULE.html#ga6d82e74ae90392733826413aaf1838e4", null ],
    [ "ETHPHY_CommandFxn", "group__BOARD__ETHPHY__MODULE.html#ga91c0f1a8b7f6e119af13a5f2ea717dd9", null ],
    [ "ETHPHY_Params_init", "group__BOARD__ETHPHY__MODULE.html#ga8ab192f315a9c2a65b946d393355346d", null ],
    [ "ETHPHY_open", "group__BOARD__ETHPHY__MODULE.html#gad9b0099a1138e12179ea1631bb2fb4bc", null ],
    [ "ETHPHY_close", "group__BOARD__ETHPHY__MODULE.html#ga698f42b85b914bea65c0573db3e56cfd", null ],
    [ "ETHPHY_command", "group__BOARD__ETHPHY__MODULE.html#gaf3051e618069fad2c94570cb618812e7", null ],
    [ "ETHPHY_getAttrs", "group__BOARD__ETHPHY__MODULE.html#ga567c1acffdb64b227ddc69c609c7093d", null ]
];
